@@ -36,9 +36,9 @@
 #'
 #'
 #' @examples
-#' data(scientometrics)
+#' data(management)
 #'
-#' results <- biblioAnalysis(scientometrics)
+#' results <- biblioAnalysis(management)
 #'
 #' summary(results, k = 10, pause = FALSE)
 #'
@@ -107,9 +107,10 @@ if ("TC" %in% Tags){
   PY=as.numeric(M$PY)
   CurrentYear=as.numeric(format(Sys.Date(),"%Y"))
   TCperYear=TC/(CurrentYear-PY+1)
-  MostCitedPapers=data.frame(M$SR,TC,TCperYear)
+  if (!("DI" %in% names(M))) M$DI <- ""
+  MostCitedPapers=data.frame(M$SR,M$DI,TC,TCperYear)
   MostCitedPapers=MostCitedPapers[order(TC,decreasing=TRUE),]
-  names(MostCitedPapers)=c("Paper         ","TC","TCperYear")
+  names(MostCitedPapers)=c("Paper         ","DOI","TC","TCperYear")
 }
 
 # References
